import os

from pathlib import Path

from nsys_recipe import nsys_constants
from nsys_recipe.lib import exceptions

def get_install_dir():
    """Return the Nsys install directory path.

    If the env var NSYS_DIR is set, return that.
    If not, deduce it from the current file path.
    """
    nsysdir = os.getenv('NSYS_DIR')
    if nsysdir is not None:
        return nsysdir

    parents = Path(__file__).parents
    if len(parents) >= 6:
        return str(parents[5].resolve())

    return None

def find_installed_file(relative_path):
    """Return the full path of the file located in the target or host
    directory."""
    install_dir = get_install_dir()

    if install_dir is not None:
        candidate_dirs = (nsys_constants.NSYS_TARGET_DIR, nsys_constants.NSYS_HOST_DIR, '')
        for candidate_dir in candidate_dirs:
            candidate = Path(install_dir) / candidate_dir / relative_path
            if candidate.exists():
                return str(candidate)

    raise exceptions.ValueError(f"Cannot find '{relative_path}'."
        " Please set NSYS_DIR to a valid Nsys install directory that contains internal dependencies.")
